/**
 * @description 路由拦截状态管理，目前两种模式：all模式与intelligence模式，其中partialRoutes是菜单暂未使用
 */
import { asyncRoutes, constantRoutes } from "@/router";
import { getRouterList } from "@/api/router";
import { convertRouter, filterRoutes } from "@/utils/routes";
import API from "@/server/api";
import Layout from "@/vab/layouts";

const state = { routes: [], partialRoutes: [] };
const getters = {
  routes: (state) => state.routes,
  partialRoutes: (state) => state.partialRoutes
};
const mutations = {
  setRoutes(state, routes) {
    state.routes = routes;
  },
  setPartialRoutes(state, routes) {
    state.partialRoutes = routes;
  }
};
const actions = {
  /**
   * @description 多模式设置路由
   * @param {*} { commit }
   * @param mode
   * @returns
   */
  async setRoutes({ commit }, mode) {
    let routes = asyncRoutes;
    if (mode === "all") {
      let data = [
        {
          path: '/',
          component: 'Layout',
          redirect: '/index',
          name: 'Home',
          meta: {
            title: '首页',
            remixIcon: 'home-4-line',
            affix: true,
          },
          children: [
            {
              path: 'index',
              name: 'Index',
              component: '@/views/index',
              meta: {
                title: '首页',
                remixIcon: 'home-4-line',
                affix: true,
              }
            },
            {
              path: 'dash',
              name: 'Dash',
              meta: {
                title: '统计首页',
                remixIcon: 'shopping-cart-line',
              },
              component: '@/views/statistics/index'
            }
          ],
        },
        {
          path: '/user',
          name: 'User',
          component: 'Layout',
          redirect: '/user/list',
          meta: {
            title: '用户管理',
            remixIcon: 'apps-line',
            roles: ['admin'],
          },
          children: [
            {
              path: 'list',
              name: '用户列表',
              component: '@/views/user/list',
              meta: {
                title: '用户列表',
                remixIcon: 'shopping-cart-line',
              }
            }
          ]
        }
      ];
      //let { data } = await API.menu();
      if (data[data.length - 1].path !== "*"){
        data.push({ path: "*", redirect: "/404", hidden: true });
      }
      routes = convertRouter(data);
    }
    const finallyRoutes = filterRoutes([...constantRoutes, ...routes]);
    commit("setRoutes", finallyRoutes);
    return [...routes];
  },
  /**
   * @description 画廊布局、综合布局设置路由
   * @param {*} { commit }
   * @param accessedRoutes 画廊布局、综合布局设置路由
   */
  setPartialRoutes({ commit }, accessedRoutes) {
    commit("setPartialRoutes", accessedRoutes);
  }
};
export default { state, getters, mutations, actions };
