/**
 * @description 登录、获取用户信息、退出登录、清除accessToken逻辑，不建议修改
 */
import Vue from "vue";
import { getUserInfo, logout } from "@/api/user";
import { getAccessToken, removeAccessToken, setAccessToken } from "@/utils/accessToken";
import { resetRouter } from "@/router";
import { title, tokenName } from "@/config";

import API from "@/server/api";

const state = {
  accessToken: getAccessToken(),
  username: "",
  avatar: "",
  user: null
};
const getters = {
  accessToken: (state) => state.accessToken,
  username: (state) => state.username,
  avatar: (state) => state.avatar,
  user: (state) => state.user
};
const mutations = {
  setAccessToken(state, accessToken) {
    state.accessToken = accessToken;
    setAccessToken(accessToken);
  },
  setUsername(state, username) {
    state.username = username;
  },
  setAvatar(state, avatar) {
    state.avatar = avatar;
  },
  setUser(state, user) {
    state.user = user;
  }
};
const actions = {
  /**
   * @description 登录拦截放行时，设置虚拟角色
   * @param {*} { commit, dispatch }
   */
  setVirtualRoles({ commit, dispatch }) {
    dispatch("acl/setFull", true, { root: true });
    commit("setAvatar", "https://i.gtimg.cn/club/item/face/img/2/15922_100.gif");
    commit("setUsername", "admin(未开启登录拦截)");
  },
  /**
   * @description 登录
   */
  async login({ commit }, userInfo) {
    const result = await API.login(userInfo);
    if (result.success) {
      const user = result.result;
      commit("setUser", user);
    }

    // 设置假的token
    const accessToken = "mmcai";
    if (accessToken) {
      commit("setAccessToken", accessToken);
    }

  },
  /**
   * @description 获取验证码
   */
  async send_msg_code({ commit }, userInfo) {
    const result = await API.send_msg_code(userInfo);
    if (result.success) {
      return result;
    }
  },
  /**
   * @description 获取用户信息接口 这个接口非常非常重要，如果没有明确底层前逻辑禁止修改此方法，错误的修改可能造成整个框架无法正常使用
   * @param {*} { commit, dispatch, state }
   * @returns
   */
  async getUserInfo({ commit, dispatch, state }) {
    let { username, avatar, roles, ability } = state.user;
    //if (username && avatar) {
      commit("setUsername", userName);
      commit("setAvatar", '');
      // 当不传递roles或ability时,默认使用管理员权限,可查看所有路由和按钮
      dispatch("acl/setFull", true, { root: true });
      // 当返回数据包含roles(角色)或ability(权限),保存至vuex
      // 如不使用roles权限控制,请不要传递roles,可删除以下代码
      //if (roles instanceof Array) dispatch("acl/setRole", roles, { root: true });
      // 如不使用ability权限控制,请不要传递ability,可删除以下代码
      //if (ability instanceof Array) dispatch("acl/setAbility", ability, { root: true });
    //}
  },

  /**
   * @description 退出登录
   * @param {*} { dispatch }
   */
  async logout({ dispatch }) {
    await logout(state.accessToken);
    await dispatch("resetAll");
  },
  /**
   * @description 重置accessToken、roles、ability、router等
   * @param {*} { commit, dispatch }
   */
  async resetAll({ dispatch }) {
    await dispatch("setAccessToken", "");
    await dispatch("acl/setFull", false, { root: true });
    await dispatch("acl/setRole", [], { root: true });
    await dispatch("acl/setAbility", [], { root: true });
    await resetRouter();
    removeAccessToken();
  },
  // 设置token
  setAccessToken({ commit }, accessToken) {
    commit("setAccessToken", accessToken);
  },
  // 设置用户
  setUser({ commit }, user) {
    commit("setUser", user);
  }
};
export default { state, getters, mutations, actions };
