/**
 * @description 路由守卫，目前两种模式：all模式与intelligence模式
 */
import router from "@/router";
import store from "@/store";
import VabProgress from "nprogress";
import "nprogress/nprogress.css";
import getPageTitle from "@/utils/pageTitle";
import {
  authentication,
  loginInterception,
  recordRoute,
  routesWhiteList
} from "@/config";

VabProgress.configure({
  easing: "ease",
  speed: 500,
  trickleSpeed: 200,
  showSpinner: false
});

//console.log(router.getRoutes(), "路由信息");

router.beforeEach(async (to, from, next) => {
  const showProgressBar = store.getters["settings/showProgressBar"];
  if (showProgressBar) VabProgress.start();
  let hasToken = store.getters["user/accessToken"];

  if (!loginInterception) hasToken = true;

  if (routesWhiteList.indexOf(to.path) !== -1) {
    if (to.path === "/login" && hasToken) next({ path: "/" });
    else next();
  } else {
    if (hasToken) {
      const hasAccess = store.getters["acl/admin"];
      if (hasAccess) {
        next();
      } else {
        try {
          if (!loginInterception) await store.dispatch("user/getUserInfo");
          //settings.js loginInterception为false（关闭登录拦截时）时，创建虚拟角色
          else await store.dispatch("user/setVirtualRoles");
          //根据路由模式添加路由
          router.addRoutes(
            await store.dispatch("routes/setRoutes", authentication)
          );
          next({ ...to, replace: true });
        } catch(err) {
          console.log(err,'啥错误');
          await store.dispatch("user/resetAll");
          if (recordRoute && to.path !== "/") {
            next({
              path: "/login",
              query: { redirect: to.path },
              replace: true
            });
          } else {
            next({ path: "/login", replace: true });
          }
        }
      }
    } else {
      if (recordRoute && to.path !== "/")
        next({ path: "/login", query: { redirect: to.path }, replace: true });
      else next({ path: "/login", replace: true });
    }
  }
});
router.afterEach((to) => {
  document.title = getPageTitle(to.meta.title);
  if (VabProgress.status) VabProgress.done();
});
